@@ -10,16 +10,7 @@ sub add {
     foo();
 }
 
-sub inc {
-    ++$a;
-    # call foo and then execute a slow expression *in the same statement*
-    # With all line profilers except NYTProf, the time for that expression gets
-    # assigned to the previous statement, i.e., the last statement executed in foo()!
-    foo() && 'aaaaaaaaaaa' =~ /((a{0,5}){0,5})*[c]/;
-}
-
 sub foo {
-    1;
     1;
     for (1..1000) {
         ++$a;
@@ -28,27 +19,54 @@ sub foo {
     1;
 }
 
+sub inc {
+    1;
+    # call foo and then execute a slow expression *in the same statement*
+    # With all line profilers except NYTProf, the time for that expression gets
+    # assigned to the previous statement, i.e., the last statement executed in foo()!
+    foo() && 'aaaaaaaaaaa' =~ /((a{0,5}){0,5})*[c]/;
+    1;
+}
+
 timethese( $count, {
     add => \&add,
     bar => \&inc,
 });
 
-
-if ($do_io) {
-    print "Enter text. Enter empty line to end.\n";
-    # With all line profilers except NYTProf, the time waiting for the
-    # second and subsequent inputs gets assigned to the previous statement,
-    # i.e., the last statement executed in the loop!
-    while (<>) {
-        chomp;
-        last if not $_;
-        1;
-    }
+END {
+    warn "ENDING\n";
+    add()
 }
 
 
+# --- recursion ---
+
+sub fib {
+    my $n = shift;
+    return $n if $n < 2;
+    fib($n-1) + fib($n-2);
+}
+fib(7);
+
+# --- File::Find ---
+
 sub wanted {
     return 1;
 }
 
 find( \&wanted, '.');
+
+
+# --- while with slow conditional ---
+
+if ($do_io) {
+    print "Enter text. Enter empty line to end.\n" if -t STDIN;
+    # time waiting for the second and subsequent inputs
+    # should get assigned to the condition statement
+    # not the last statement executed in the loop
+    while (<>) {
+        chomp;
+        last if not $_;
+        1;
+    }
+}
